@@ -1,4 +1,4 @@
-from .topics import Topic
+from .topics import Topic, Topics
 from .lda import LdaWrapper
 from .lsi import LsiWrapper
 from .hdp import HdpWrapper
